@@ -23,25 +23,28 @@ import stat
 from calculate.core.server.gen_pid import search_worked_process2
 from calculate.core.setup_package import ChainProgressTemplate
 from calculate.lib.datavars import DataVars
-from calculate.lib.utils.colortext import TextState, get_color_print, \
-    convert_console_to_xml
+from calculate.lib.utils.colortext import (TextState, get_color_print,
+    convert_console_to_xml)
 from calculate.lib.utils.files import (
     pathJoin, PercentProgress, getProgPath, process, STDOUT, removeDir,
     makeDirectory, writeFile, readLinesFile, chmod, chown, FilePermission,
-    find, FindFileType, removeFileWithEmptyDirectory,
+    find, FindFileType, removeFileWithEmptyDirectory, check_rw,
     copyWithPath, countFiles, listDirectory, getRunCommands, isMount, readFile)
 from calculate.lib.utils.git import Git
-from calculate.lib.utils.portage import Layman, EmergeLog, EmergeLogNamedTask, \
-    InstalledPackageInfo, EbuildInfoError, EbuildInfo, ChrootEix, \
-    get_packages_files_directory, get_manifest_files_directory
-from calculate.update.emerge_parser import EmergeParser, \
-    EmergeError, EmergeCommand, Chroot, Linux32, CommandExecutor, \
-    RevdepPercentBlock, EmergeCache
+from calculate.lib.utils.portage import (Layman, EmergeLog, EmergeLogNamedTask,
+                                         InstalledPackageInfo, EbuildInfoError,
+                                         EbuildInfo, ChrootEix,
+                                         get_packages_files_directory,
+                                         get_manifest_files_directory)
+from calculate.update.emerge_parser import (EmergeParser,
+                                            EmergeError, EmergeCommand, Chroot,
+                                            Linux32, CommandExecutor,
+                                            RevdepPercentBlock, EmergeCache)
 from calculate.lib.cl_log import log
 from .build_storage import Build
 from calculate.update.update import Update
-from calculate.install.distr import Distributive, IsoDistributive, \
-    DistributiveError
+from calculate.install.distr import (Distributive, IsoDistributive,
+                                     DistributiveError)
 from functools import partial
 import os
 from os import path
@@ -1136,6 +1139,8 @@ class Builder(Update):
         if p.failed():
             self.printERROR(p.read().strip())
             return False
+        if not check_rw(dn):
+            raise BuilderError("Selected device is read-only")
         return True
 
     def sync_vmlinuz(self, flash_dn):
